@@ -96,6 +96,28 @@
 	i(GLU_V_STEP)
 #endif
 
+#ifdef GLU_VERSION_1_2
+          i(GLU_TESS_ERROR)
+          i(GLU_TESS_BEGIN)
+          i(GLU_TESS_EDGE_FLAG)
+          i(GLU_TESS_VERTEX)
+          i(GLU_TESS_COMBINE)
+          i(GLU_TESS_END)
+          i(GLU_TESS_ERROR_DATA)
+          i(GLU_TESS_BEGIN_DATA)
+          i(GLU_TESS_EDGE_FLAG_DATA)
+          i(GLU_TESS_VERTEX_DATA)
+          i(GLU_TESS_COMBINE_DATA)
+          i(GLU_TESS_END_DATA)
+          i(GLU_TESS_WINDING_RULE)
+          i(GLU_TESS_WINDING_ODD)
+          i(GLU_TESS_WINDING_NONZERO)
+          i(GLU_TESS_WINDING_POSITIVE)
+          i(GLU_TESS_WINDING_NEGATIVE)
+          i(GLU_TESS_WINDING_ABS_GEQ_TWO)
+
+# endif
+
 /* 75 */
 #ifdef GLU_EXT_object_space_tess
 	i(GLU_OBJECT_PARAMETRIC_ERROR_EXT)
